==> gnome-panel-2.21.90.tar.gz: gnome-panel-2.21.90/applets/clock/clock-marshallers.h <==

#ifndef ___clock_marshal_MARSHAL_H__
#define ___clock_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:VOID (clock-marshallers.list:1) */
#define _clock_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

/* VOID:OBJECT (clock-marshallers.list:2) */
#define _clock_marshal_VOID__OBJECT	g_cclosure_marshal_VOID__OBJECT

/* VOID:POINTER (clock-marshallers.list:3) */
#define _clock_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER

/* POINTER:VOID (clock-marshallers.list:4) */
G_GNUC_INTERNAL void _clock_marshal_POINTER__VOID (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);

/* VOID:OBJECT,STRING (clock-marshallers.list:5) */
G_GNUC_INTERNAL void _clock_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                                         GValue       *return_value,
                                                         guint         n_param_values,
                                                         const GValue *param_values,
                                                         gpointer      invocation_hint,
                                                         gpointer      marshal_data);

/* STRING:VOID (clock-marshallers.list:6) */
G_GNUC_INTERNAL void _clock_marshal_STRING__VOID (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
                                                  const GValue *param_values,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);

G_END_DECLS

#endif /* ___clock_marshal_MARSHAL_H__ */

==> gnome-panel-2.23.5.tar.gz: gnome-panel-2.23.5/applets/clock/clock-marshallers.h <==

#ifndef ___clock_marshal_MARSHAL_H__
#define ___clock_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* POINTER:VOID (clock-marshallers.list:1) */
G_GNUC_INTERNAL void _clock_marshal_POINTER__VOID (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);

/* VOID:OBJECT,STRING (clock-marshallers.list:2) */
G_GNUC_INTERNAL void _clock_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                                         GValue       *return_value,
                                                         guint         n_param_values,
                                                         const GValue *param_values,
                                                         gpointer      invocation_hint,
                                                         gpointer      marshal_data);

/* INT:VOID (clock-marshallers.list:3) */
G_GNUC_INTERNAL void _clock_marshal_INT__VOID (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);

G_END_DECLS

#endif /* ___clock_marshal_MARSHAL_H__ */
